Welcome to selexe’s documentation! — selexe v0.1.0 documentation

### Navigation

- index
- next |
- selexe v0.1.0 documentation »

# Welcome to selexe’s documentation!

selexe is a tool to directly execute selenese files (i.e. *.sel files) created by the selenium IDE. Selenium commands are directly translated into Python executable code without the need of manually converting selenese files into Python code first.

This documentation applies to selexe release V 0.1.0

Contents:

- selexe
  - What It Does
  - Changes
  - Supported Platforms
  - License
  - Quick Installation
  - Documentation
  - Support
  - Missing Features
- Installation
- selexe manual
- This is the MIT license

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- selexe v0.1.0 documentation »